package de.intevation.flys.exports;


import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;

import de.intevation.artifactdatabase.state.Attribute;
import de.intevation.artifactdatabase.state.DefaultSection;


/**
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public class AxisSection extends DefaultSection {

    public static final String IDENTIFIER_ATTR = "id";
    public static final String LABEL_ATTR      = "label";


    public AxisSection() {
        super("axis");
    }


    public void setIdentifier(String identifier) {
        if (identifier == null || identifier.length() == 0) {
            return;
        }

        Attribute attr = getAttribute(IDENTIFIER_ATTR);
        if (attr == null) {
            attr = new StringAttribute(IDENTIFIER_ATTR, identifier, false);
            addAttribute(IDENTIFIER_ATTR, attr);
        }
        else {
            attr.setValue(identifier);
        }
    }


    public void setLabel(String label) {
        if (label == null) {
            return;
        }

        Attribute attr = getAttribute(LABEL_ATTR);
        if (attr == null) {
            attr = new StringAttribute(LABEL_ATTR, label, true);
            addAttribute(LABEL_ATTR, attr);
        }
        else {
            attr.setValue(label);
        }
    }


    @Override
    public void toXML(Node parent) {
        Document owner = parent.getOwnerDocument();
        Element   axis = owner.createElement("axis");

        parent.appendChild(axis);

        for (String key: getKeys()) {
            Attribute attr = getAttribute(key);
            attr.toXML(axis);
        }
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
